@@ -9,7 +9,7 @@
 //  Module:         Application configuration data
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -37,12 +37,12 @@
 #include <qcolor.h>
 #include <qfont.h>
 
-#include "libewf.h"
-
 #include "toolcfg.h"
 #include "toolsysinfo.h"
 #include "file.h"
 
+#include "ewf.h"
+
 #include "qtutil.h"
 #include "util.h"
 #include "config.h"
@@ -265,24 +265,26 @@ static t_ToolCfgSet SetArrEwfFormat[] =
 {
    // Name in cfg file   Corresponding value
    // ------------------------------------------
-   {  "Encase1" ,         LIBEWF_FORMAT_ENCASE1},
-   {  "Encase2" ,         LIBEWF_FORMAT_ENCASE2},
-   {  "Encase3" ,         LIBEWF_FORMAT_ENCASE3},
-   {  "Encase4" ,         LIBEWF_FORMAT_ENCASE4},
-   {  "Encase5" ,         LIBEWF_FORMAT_ENCASE5},
-   {  "Encase6" ,         LIBEWF_FORMAT_ENCASE6},
-   {  "Smart"   ,         LIBEWF_FORMAT_SMART  },
-   {  "FTK"     ,         LIBEWF_FORMAT_FTK    },
-   {  "Linen5"  ,         LIBEWF_FORMAT_LINEN5 },
-   {  "Linen6"  ,         LIBEWF_FORMAT_LINEN6 },
-   #if (LIBEWF_VERSION >= 20130416)
-   {  "Encase7" ,         LIBEWF_FORMAT_ENCASE7},
-   {  "Linen7"  ,         LIBEWF_FORMAT_LINEN7 },
-   {  "EWFX"    ,         LIBEWF_FORMAT_EWFX   },
+   #if (ENABLE_LIBEWF)
+      {  "Encase1" ,         LIBEWF_FORMAT_ENCASE1},
+      {  "Encase2" ,         LIBEWF_FORMAT_ENCASE2},
+      {  "Encase3" ,         LIBEWF_FORMAT_ENCASE3},
+      {  "Encase4" ,         LIBEWF_FORMAT_ENCASE4},
+      {  "Encase5" ,         LIBEWF_FORMAT_ENCASE5},
+      {  "Encase6" ,         LIBEWF_FORMAT_ENCASE6},
+      {  "Smart"   ,         LIBEWF_FORMAT_SMART  },
+      {  "FTK"     ,         LIBEWF_FORMAT_FTK    },
+      {  "Linen5"  ,         LIBEWF_FORMAT_LINEN5 },
+      {  "Linen6"  ,         LIBEWF_FORMAT_LINEN6 },
+      #if (LIBEWF_VERSION >= 20130416)
+      {  "Encase7" ,         LIBEWF_FORMAT_ENCASE7},
+      {  "Linen7"  ,         LIBEWF_FORMAT_LINEN7 },
+      {  "EWFX"    ,         LIBEWF_FORMAT_EWFX   },
+      #endif
    #endif
-   {  "Guymager",         t_File::AEWF         }, // AEWF format is a format on its own (for the function calls) and at the same time a
-   {  "AEWF"    ,         t_File::AEWF         }, // subformat of EWF (for the user interface). Looks a bit strange at first sight, but
-   {   NULL     ,         0                    }  // probably is the best compromise.
+   {     "Guymager",         t_File::AEWF         }, // AEWF format is a format on its own (for the function calls) and at the same time a
+   {     "AEWF"    ,         t_File::AEWF         }, // subformat of EWF (for the user interface). Looks a bit strange at first sight, but
+   {      NULL     ,         0                    }  // probably is the best compromise.
 };
 
 
