@@ -9,7 +9,7 @@
 //  Module:         Acquisition dialog
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -1301,13 +1301,14 @@ void t_DlgAcquire::Accept (bool DuplicatePressed)
             return;
          }
          SplitSize = NumValue * UnitIndexToMultiplier (DlgAcquireGetField(CFG_DLGACQUIRE_SPLITFILEUNIT)->pComboBox->currentIndex());
-         #if ((LIBEWF_VERSION != 20080501) && (LIBEWF_VERSION != 20100226) && (LIBEWF_VERSION != 20111015) && (LIBEWF_VERSION < 20130416))
-            #error "Please check EWF documentation for newer Encase formats and adjust following code"
-         #endif
          if (pOwn->pRadioButtonFormatEWF->isChecked())
          {
-            if ((CONFIG(EwfFormat) == LIBEWF_FORMAT_ENCASE6) ||
-                (CONFIG(EwfFormat) == t_File::AEWF))
+            #if (ENABLE_LIBEWF)
+               if ((CONFIG(EwfFormat) == LIBEWF_FORMAT_ENCASE6) ||
+                   (CONFIG(EwfFormat) == t_File::AEWF))
+            #else
+               if (CONFIG(EwfFormat) == t_File::AEWF)
+            #endif
             {
                if ((SplitSize > EWF_MAX_SEGMENT_SIZE_EXT) || (SplitSize < EWF_MIN_SEGMENT_SIZE))
                {
