@@ -9,7 +9,7 @@
 //  Module:         Everything related to file names, extension names, paths...
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -31,7 +31,7 @@
 
 #include <QtCore>
 
-#include "libewf.h"
+#include "ewf.h"
 
 #include "util.h"
 #include "device.h"
@@ -70,24 +70,26 @@ APIRET t_File::GetFormatDescription (t_Format Format, bool Clone, int DdSplitDec
       case EWF:
          switch (CONFIG(EwfFormat))
          {
-            case LIBEWF_FORMAT_ENCASE1: SubFormat="Encase1" ; break;
-            case LIBEWF_FORMAT_ENCASE2: SubFormat="Encase2" ; break;
-            case LIBEWF_FORMAT_ENCASE3: SubFormat="Encase3" ; break;
-            case LIBEWF_FORMAT_ENCASE4: SubFormat="Encase4" ; break;
-            case LIBEWF_FORMAT_ENCASE5: SubFormat="Encase5" ; break;
-            case LIBEWF_FORMAT_ENCASE6: SubFormat="Encase6" ; break;
-            case LIBEWF_FORMAT_FTK    : SubFormat="FTK"     ; break;
-            case LIBEWF_FORMAT_SMART  : SubFormat="Smart"   ; break;
-            case LIBEWF_FORMAT_LVF    : SubFormat="LVF"     ; break;
-            case LIBEWF_FORMAT_LINEN5 : SubFormat="Linen5"  ; break;
-            case LIBEWF_FORMAT_LINEN6 : SubFormat="Linen6"  ; break;
-            #if (LIBEWF_VERSION >= 20130416)
-            case LIBEWF_FORMAT_ENCASE7: SubFormat="Encase7" ; break;
-            case LIBEWF_FORMAT_LINEN7 : SubFormat="Linen7"  ; break;
-            case LIBEWF_FORMAT_EWFX   : SubFormat="EWFX"    ; break;
+            #if (ENABLE_LIBEWF)
+               case LIBEWF_FORMAT_ENCASE1: SubFormat="Encase1" ; break;
+               case LIBEWF_FORMAT_ENCASE2: SubFormat="Encase2" ; break;
+               case LIBEWF_FORMAT_ENCASE3: SubFormat="Encase3" ; break;
+               case LIBEWF_FORMAT_ENCASE4: SubFormat="Encase4" ; break;
+               case LIBEWF_FORMAT_ENCASE5: SubFormat="Encase5" ; break;
+               case LIBEWF_FORMAT_ENCASE6: SubFormat="Encase6" ; break;
+               case LIBEWF_FORMAT_FTK    : SubFormat="FTK"     ; break;
+               case LIBEWF_FORMAT_SMART  : SubFormat="Smart"   ; break;
+               case LIBEWF_FORMAT_LVF    : SubFormat="LVF"     ; break;
+               case LIBEWF_FORMAT_LINEN5 : SubFormat="Linen5"  ; break;
+               case LIBEWF_FORMAT_LINEN6 : SubFormat="Linen6"  ; break;
+               #if (LIBEWF_VERSION >= 20130416)
+                  case LIBEWF_FORMAT_ENCASE7: SubFormat="Encase7" ; break;
+                  case LIBEWF_FORMAT_LINEN7 : SubFormat="Linen7"  ; break;
+                  case LIBEWF_FORMAT_EWFX   : SubFormat="EWFX"    ; break;
+               #endif
             #endif
-            case AEWF                 : SubFormat="Guymager"; break;
-            default                   : CHK (ERROR_FILE_INVALID_EWF_FORMAT)
+            case AEWF: SubFormat="Guymager"; break;
+            default  : CHK (ERROR_FILE_INVALID_EWF_FORMAT)
          }
          Str = QObject::tr("Expert Witness Format, sub-format %1") .arg(SubFormat);
          break;
@@ -126,22 +128,24 @@ APIRET t_File::GetFormatExtension (t_Format Format, bool Clone, int DdSplitDecim
       case EWF:
          switch (CONFIG(EwfFormat))
          {
-            case LIBEWF_FORMAT_ENCASE1:
-            case LIBEWF_FORMAT_ENCASE2:
-            case LIBEWF_FORMAT_ENCASE3:
-            case LIBEWF_FORMAT_ENCASE4:
-            case LIBEWF_FORMAT_ENCASE5:
-            case LIBEWF_FORMAT_ENCASE6:
-            case LIBEWF_FORMAT_LINEN5 :
-            case LIBEWF_FORMAT_LINEN6 :
-            #if (LIBEWF_VERSION >= 20130416)
-            case LIBEWF_FORMAT_ENCASE7:
-            case LIBEWF_FORMAT_LINEN7 :
-            case LIBEWF_FORMAT_EWFX   :
+            #if (ENABLE_LIBEWF)
+               case LIBEWF_FORMAT_SMART  : Wild=".s??"; Human=".sxx"; break;
+               case LIBEWF_FORMAT_ENCASE1:
+               case LIBEWF_FORMAT_ENCASE2:
+               case LIBEWF_FORMAT_ENCASE3:
+               case LIBEWF_FORMAT_ENCASE4:
+               case LIBEWF_FORMAT_ENCASE5:
+               case LIBEWF_FORMAT_ENCASE6:
+               case LIBEWF_FORMAT_LINEN5 :
+               case LIBEWF_FORMAT_LINEN6 :
+               #if (LIBEWF_VERSION >= 20130416)
+                  case LIBEWF_FORMAT_ENCASE7:
+                  case LIBEWF_FORMAT_LINEN7 :
+                  case LIBEWF_FORMAT_EWFX   :
+               #endif
+               case LIBEWF_FORMAT_FTK :
             #endif
-            case LIBEWF_FORMAT_FTK    :
             case AEWF                 : Wild=".E??"; Human=".Exx"; break;
-            case LIBEWF_FORMAT_SMART  : Wild=".s??"; Human=".sxx"; break;
             default                   : CHK (ERROR_FILE_INVALID_EWF_FORMAT)
          }
          break;
