@@ -4,13 +4,13 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="+580"/>
+        <location filename="main.cpp" line="+582"/>
         <source>Guymager needs to be started with root rights in order to perform acquisitions. You are not root and thus won&apos;t be able to acquire devices.
 Continue anyway?</source>
         <translation type="unfinished">GUYMAGER需要以管理员的身份运行，你目前不是管理员权限，确定继续吗？</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1482"/>
+        <location filename="threadwrite.cpp" line="+1491"/>
         <source>Deleting %1</source>
         <translation type="unfinished">删除 %1</translation>
     </message>
@@ -41,7 +41,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+26"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -71,7 +71,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-29"/>
+        <location filename="file.cpp" line="-31"/>
         <source>Creation of a clone</source>
         <translation type="unfinished">创建一个克隆</translation>
     </message>
@@ -305,7 +305,7 @@ Do you accept these changes?</source>
     </message>
     <message>
         <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+346"/>
+        <location filename="table.cpp" line="+351"/>
         <source>EwfCaseNumber</source>
         <translation type="unfinished">案件序列号</translation>
     </message>
@@ -356,7 +356,7 @@ Do you accept these changes?</source>
         <translation type="unfinished">文件扩展名%1</translation>
     </message>
     <message>
-        <location line="+688"/>
+        <location line="+689"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">特殊字符</translation>
@@ -372,7 +372,7 @@ Do you accept these changes?</source>
         <translation type="unfinished">信息目录</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1075"/>
+        <location filename="dlgacquire.cpp" line="-1076"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation type="unfinished"></translation>
@@ -436,7 +436,7 @@ This may be due to insufficient access rights or unsupported filename characters
         <translation type="unfinished">可以进行拷贝</translation>
     </message>
     <message>
-        <location line="+862"/>
+        <location line="+863"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation type="unfinished"></translation>
     </message>
@@ -460,7 +460,7 @@ Do you accept these changes?</source>
         <translation type="unfinished">图像或信息文件已存在，确定覆盖吗？</translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-882"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation type="unfinished">拷贝%1</translation>
@@ -498,19 +498,19 @@ Do you accept these changes?</source>
     </message>
     <message>
         <location line="+618"/>
-        <location line="+15"/>
+        <location line="+16"/>
         <location line="+12"/>
         <source>Incorrect value</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">错误的值</translation>
     </message>
     <message>
-        <location line="-26"/>
+        <location line="-27"/>
         <source>The split file size &quot;%1&quot; is not valid. Only positive numbers can be entered.</source>
         <translation type="unfinished">分卷大小“%1”是无效的。只能输入一个正数。</translation>
     </message>
     <message>
-        <location line="+163"/>
+        <location line="+164"/>
         <source>Files already used</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -563,7 +563,7 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1096"/>
+        <location filename="dlgacquire.cpp" line="-1097"/>
         <source>Selected for first acquisition</source>
         <translation type="unfinished"></translation>
     </message>
@@ -593,7 +593,7 @@ doesn&apos;t exist. Do you want to create it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+169"/>
+        <location line="+170"/>
         <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -650,7 +650,7 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-595"/>
+        <location line="-596"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation type="unfinished"></translation>
@@ -667,7 +667,7 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+906"/>
+        <location line="+907"/>
         <source>There possibly is not enough space left on the destination path.
 Source data size: %1
 Free space on destination: %2
@@ -917,7 +917,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+201"/>
+        <location line="+200"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -945,11 +945,34 @@ Using libguytools %5</source>
 版本：1.0</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+18"/>
+        <location line="+14"/>
         <source>About GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">关于GUYMAGER</translation>
     </message>
+    <message>
+        <location line="-13"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Linked with libewf %5 %6</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+16"/>
         <source>About Qt</source>
@@ -957,13 +980,13 @@ Using libguytools %5</source>
         <translation type="unfinished">关于QT</translation>
     </message>
     <message>
-        <location line="-86"/>
+        <location line="-103"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation type="unfinished">退出</translation>
     </message>
     <message>
-        <location line="-356"/>
+        <location line="-355"/>
         <source>&amp;Devices</source>
         <translation type="unfinished">&amp;D设备</translation>
     </message>
@@ -1057,7 +1080,7 @@ Using libguytools %5</source>
         <translation type="unfinished">添加特殊设备</translation>
     </message>
     <message>
-        <location line="+161"/>
+        <location line="+160"/>
         <source>Open File</source>
         <translation type="unfinished">打开文件</translation>
     </message>
@@ -1116,26 +1139,15 @@ Using libguytools %5</source>
         <translation type="unfinished">未知</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-179"/>
+        <location filename="mainwindow.cpp" line="-178"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished">在获取完成后退出</translation>
     </message>
     <message>
-        <location line="+417"/>
+        <location line="+416"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location line="+3"/>
-        <source>GUYMAGER is a Linux-based forensic imaging tool
-
-Version: %1
-Compilation timestamp: %2
-Compiled with gcc %3
-Linked with libewf %4 %5
-Linked with libguytools %6</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="device.cpp" line="-468"/>
         <source>Acquisition start failure</source>
@@ -1278,7 +1290,7 @@ Linked with libguytools %6</source>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-190"/>
+        <location filename="table.cpp" line="-195"/>
         <source>Local Device - cannot be acquired</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1295,19 +1307,19 @@ Linked with libguytools %6</source>
         <translation type="unfinished">设备信息</translation>
     </message>
     <message>
-        <location line="+26"/>
+        <location line="+25"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation type="unfinished">GUYMAGER取信息文件</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+12"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation type="unfinished">GUYMAGER</translation>
     </message>
     <message>
-        <location line="+14"/>
+        <location line="+21"/>
         <source>Device information</source>
         <comment>Info file</comment>
         <translation type="unfinished">设备信息</translation>
@@ -1445,7 +1457,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-619"/>
+        <location line="-626"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1463,13 +1475,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+1"/>
-        <source>libewf version:: %1</source>
-        <comment>Info file</comment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location line="+1"/>
+        <location line="+9"/>
         <source>libguytools version:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1511,7 +1517,26 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-36"/>
+        <location line="-42"/>
+        <source>(not used as Guymager is configured to use its own EWF module)</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>libewf version:: %1 %2</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Using Guymager&apos;s own EWF module</source>
+        <oldsource>No libewf support, using Guymager&apos;s own EWF module</oldsource>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
         <source>Host name:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1615,13 +1640,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-839"/>
+        <location line="-844"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+222"/>
+        <location line="+227"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1633,7 +1658,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-222"/>
+        <location line="-227"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
@@ -1651,7 +1676,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+212"/>
+        <location line="+217"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1663,12 +1688,12 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-178"/>
+        <location line="-183"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+861"/>
+        <location line="+866"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1684,12 +1709,12 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-876"/>
+        <location line="-881"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+734"/>
+        <location line="+739"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
