@@ -4,7 +4,7 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="main.cpp" line="+579"/>
+        <location filename="main.cpp" line="+581"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Keine Root-Rechte</translation>
@@ -17,7 +17,7 @@ Continue anyway?</source>
 Trotzdem fortfahren?</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1482"/>
+        <location filename="threadwrite.cpp" line="+1491"/>
         <source>Deleting %1</source>
         <translation>Lösche %1</translation>
     </message>
@@ -42,7 +42,7 @@ Trotzdem fortfahren?</translation>
         <translation>Linux dd-Image</translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+26"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation>EWF-Format, Unterformat %1</translation>
     </message>
@@ -72,7 +72,7 @@ Trotzdem fortfahren?</translation>
         <translation>Methode &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-29"/>
+        <location filename="file.cpp" line="-31"/>
         <source>Creation of a clone</source>
         <translation>Erstellen eines Klons</translation>
     </message>
@@ -317,7 +317,7 @@ Geschwindigkeit
     <name>t_DlgAcquire</name>
     <message>
         <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+346"/>
+        <location filename="table.cpp" line="+351"/>
         <source>EwfCaseNumber</source>
         <translation>Fallnummer</translation>
     </message>
@@ -393,7 +393,7 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation>(Datei-Endung %1)</translation>
     </message>
     <message>
-        <location line="+688"/>
+        <location line="+689"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation>Sonderzeichen</translation>
@@ -409,7 +409,7 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation>Info-Verzeichnis</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1075"/>
+        <location filename="dlgacquire.cpp" line="-1076"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation>...</translation>
@@ -473,7 +473,7 @@ This may be due to insufficient access rights or unsupported filename characters
         <translation>Bereit zum Klonen</translation>
     </message>
     <message>
-        <location line="+862"/>
+        <location line="+863"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation>Die Split-Grösse für das konfigurierte EWF-Format muss im Bereich %1 MiB - %2 MiB liegen. Grössere Dateien sind mit den Format Encase6 oder Guymager möglich (siehe Guymager Konfigurationsdatei, Parameter EwfFormat).</translation>
     </message>
@@ -496,7 +496,7 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
         <translation>Die Image- oder Info-Dateien existieren bereits. Möchten Sie sie überschreiben?</translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-882"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation>Gerät %1 klonen</translation>
@@ -534,19 +534,19 @@ Sind Sie mit diesen Änderungen einverstanden?</translation>
     </message>
     <message>
         <location line="+618"/>
-        <location line="+15"/>
+        <location line="+16"/>
         <location line="+12"/>
         <source>Incorrect value</source>
         <comment>Dialog title</comment>
         <translation>Ungültiger Wert</translation>
     </message>
     <message>
-        <location line="-26"/>
+        <location line="-27"/>
         <source>The split file size &quot;%1&quot; is not valid. Only positive numbers can be entered.</source>
         <translation>Die Grösse %1 für die Split-Dateien ist ungültig. Bitte geben Sie einen positiven Wert ein.</translation>
     </message>
     <message>
-        <location line="+163"/>
+        <location line="+164"/>
         <source>Files already used</source>
         <comment>Dialog title</comment>
         <translation>Datei bereits belegt</translation>
@@ -619,7 +619,7 @@ Möchten Sie die Akquisition trotzdem starten?</translation>
         <translation>SHA-1 berechnen</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1096"/>
+        <location filename="dlgacquire.cpp" line="-1097"/>
         <source>Selected for first acquisition</source>
         <translation>Als 1. Akquisitionsziel ausgewählt</translation>
     </message>
@@ -651,7 +651,7 @@ doesn&apos;t exist. Do you want to create it?</source>
 existiert nicht. Möchten Sie es anlegen?</translation>
     </message>
     <message>
-        <location line="+169"/>
+        <location line="+170"/>
         <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
         <translation>Die Verzeichnis- oder Dateinamen enthält unerlaubte Sonderzeichen. Guymager schlägt stattdessen folgenden Namen vor:</translation>
     </message>
@@ -708,7 +708,7 @@ Do you accept these changes?</source>
         <translation>Die Info-Datei ist bereits durch das erste Image belegt.</translation>
     </message>
     <message>
-        <location line="-595"/>
+        <location line="-596"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation>Zurück...</translation>
@@ -725,7 +725,7 @@ Do you accept these changes?</source>
         <translation>Einstellungen für dupliziertes Image</translation>
     </message>
     <message>
-        <location line="+906"/>
+        <location line="+907"/>
         <source>There possibly is not enough space left on the destination path.
 Source data size: %1
 Free space on destination: %2
@@ -978,7 +978,7 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>F5</translation>
     </message>
     <message>
-        <location line="+201"/>
+        <location line="+200"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation>Gerät bereits vorhanden</translation>
@@ -994,7 +994,8 @@ Guymager beendet sich automatisch in %1 Sekunden.</translation>
         <translation>Debug-Informationen</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+18"/>
+        <location line="+14"/>
         <source>About GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>Über GUYMAGER</translation>
@@ -1016,19 +1017,19 @@ Benutzt libewf %4
 Benutzt libguytools %5</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+17"/>
         <source>About Qt</source>
         <comment>Dialog title</comment>
         <translation>Über Qt</translation>
     </message>
     <message>
-        <location line="-86"/>
+        <location line="-103"/>
         <source>Exit GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>GUYMAGER verlassen</translation>
     </message>
     <message>
-        <location line="-356"/>
+        <location line="-355"/>
         <source>&amp;Devices</source>
         <translation>&amp;Geräte</translation>
     </message>
@@ -1062,6 +1063,40 @@ Benutzt libguytools %5</translation>
         <comment>Menu entry</comment>
         <translation>Über &amp;Qt</translation>
     </message>
+    <message>
+        <location line="+413"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Linked with libewf %5 %6</source>
+        <translation>GUYMAGER ist ein Linux-basierter, forensischer Imager
+
+Version: %1
+Zeitstempel der Kompilation: %2
+Kompiliert mit gcc %3
+Benutzt libguytools %4
+Benutzt libewf %5 %6</translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</source>
+        <translation>GUYMAGER ist ein Linux-basierter, forensischer Imager
+
+Version: %1
+Zeitstempel der Kompilation: %2
+Kompiliert mit gcc %3
+Benutzt libguytools %4
+Ohne libewf-Unterstützung kompiliert.</translation>
+    </message>
     <message>
         <source>Acquisition running</source>
         <translation type="obsolete">Akquisition läuft</translation>
@@ -1111,7 +1146,7 @@ Benutzt libguytools %5</translation>
         <translation>Ja</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-19"/>
+        <location filename="mainwindow.cpp" line="-446"/>
         <source>Rescan devices and update table</source>
         <translation>Geräte neu einlesen und Tabelle auffrischen</translation>
     </message>
@@ -1122,7 +1157,7 @@ Benutzt libguytools %5</translation>
         <translation>Sondergerät hinzufügen</translation>
     </message>
     <message>
-        <location line="+161"/>
+        <location line="+160"/>
         <source>Open File</source>
         <translation>Datei öffnen</translation>
     </message>
@@ -1181,7 +1216,7 @@ Benutzt libguytools %5</translation>
         <translation>nicht feststellbar</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-179"/>
+        <location filename="mainwindow.cpp" line="-178"/>
         <source>Exit after acquisitions completed</source>
         <translation>Guymager nach Abschluss aller Akquisitionen beenden</translation>
     </message>
@@ -1194,12 +1229,11 @@ Benutzt libguytools %5</translation>
         <translation type="obsolete">Abbruch - Startfehler Akquisition</translation>
     </message>
     <message>
-        <location line="+417"/>
+        <location line="+416"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation>(inaktiv, da das Guymager-interne EWF-Modul konfiguriert ist)</translation>
     </message>
     <message>
-        <location line="+3"/>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
@@ -1207,7 +1241,7 @@ Compilation timestamp: %2
 Compiled with gcc %3
 Linked with libewf %4 %5
 Linked with libguytools %6</source>
-        <translation>GUYMAGER ist ein Linux-basierter, forensischer Imager
+        <translation type="vanished">GUYMAGER ist ein Linux-basierter, forensischer Imager
 
 Version: %1
 Zeitstempel der Kompilation: %2
@@ -1362,7 +1396,7 @@ Benutzt libguytools %6</translation>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-190"/>
+        <location filename="table.cpp" line="-195"/>
         <source>Local Device - cannot be acquired</source>
         <translation>Lokales Gerät - kann nicht akquiriert werden</translation>
     </message>
@@ -1379,19 +1413,38 @@ Benutzt libguytools %6</translation>
         <translation>Geräte-Informationen</translation>
     </message>
     <message>
-        <location line="+26"/>
+        <location line="+25"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation>GUYMAGER INFO-DATEI ZUR AKQUISITION</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+12"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation>Guymager</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+8"/>
+        <source>(not used as Guymager is configured to use its own EWF module)</source>
+        <comment>Info file</comment>
+        <translation>(inaktiv, da das Guymager-interne EWF-Modul konfiguriert ist)</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>libewf version:: %1 %2</source>
+        <comment>Info file</comment>
+        <translation>Version libewf:: %1 %2</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Using Guymager&apos;s own EWF module</source>
+        <oldsource>No libewf support, using Guymager&apos;s own EWF module</oldsource>
+        <comment>Info file</comment>
+        <translation>Verwendung des Guymager-internen EWF-Modul</translation>
+    </message>
+    <message>
+        <location line="+3"/>
         <source>Host name:: %1</source>
         <comment>Info file</comment>
         <translation>Host-Name:: %1</translation>
@@ -1547,7 +1600,7 @@ Benutzt libguytools %6</translation>
         <translation>MD5-Hash:: %1</translation>
     </message>
     <message>
-        <location line="-619"/>
+        <location line="-626"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation>Version:: %1</translation>
@@ -1565,13 +1618,12 @@ Benutzt libguytools %6</translation>
         <translation>Kompiliert mit:: %1 %2</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>libewf version:: %1</source>
         <comment>Info file</comment>
-        <translation>Version libewf:: %1</translation>
+        <translation type="vanished">Version libewf:: %1</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+9"/>
         <source>libguytools version:: %1</source>
         <comment>Info file</comment>
         <translation>Version libguytools:: %1</translation>
@@ -1719,13 +1771,13 @@ Benutzt libguytools %6</translation>
         <translation>Versuchen Sie eine erneute Akquisition.</translation>
     </message>
     <message>
-        <location line="-839"/>
+        <location line="-844"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation>Sondergerät entfernen</translation>
     </message>
     <message>
-        <location line="+222"/>
+        <location line="+227"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation>Image Meta-Daten </translation>
@@ -1737,7 +1789,7 @@ Benutzt libguytools %6</translation>
         <translation> - mit Datei-Endung %1</translation>
     </message>
     <message>
-        <location line="-222"/>
+        <location line="-227"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation>Image-Datei erstellen</translation>
@@ -1755,7 +1807,7 @@ Benutzt libguytools %6</translation>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location line="+212"/>
+        <location line="+217"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation>Akquisition</translation>
@@ -1767,12 +1819,12 @@ Benutzt libguytools %6</translation>
         <translation>Format:: %1</translation>
     </message>
     <message>
-        <location line="-178"/>
+        <location line="-183"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation>Gerät durch Klon-Operation belegt - kann nicht akquiriert werden</translation>
     </message>
     <message>
-        <location line="+861"/>
+        <location line="+866"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation>Erzeugte Image-Dateien und ihre MD5-Hashwerte</translation>
@@ -1792,12 +1844,12 @@ Benutzt libguytools %6</translation>
         <translation>Keine MD5-Hashes verfügbar (der Konfigurationsparameter CalcImageFileMD5 ist abgeschaltet)</translation>
     </message>
     <message>
-        <location line="-876"/>
+        <location line="-881"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation>Kann nicht akquiriert werden - siehe Status-Zusatzinformation</translation>
     </message>
     <message>
-        <location line="+734"/>
+        <location line="+739"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation>Abbruch wegen Fehler beim Schreiben der Image-Datei</translation>
