@@ -24,12 +24,12 @@
         <translation>Image brute Linux dd</translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+26"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation>Format EWF, sous-format %1 </translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+579"/>
+        <location filename="main.cpp" line="+581"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Droits «root»</translation>
@@ -42,7 +42,7 @@ Continue anyway?</source>
 Continuer quand-même?</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1482"/>
+        <location filename="threadwrite.cpp" line="+1491"/>
         <source>Deleting %1</source>
         <translation>Efface %1</translation>
     </message>
@@ -72,7 +72,7 @@ Continuer quand-même?</translation>
         <translation>Essayer la méthode &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-29"/>
+        <location filename="file.cpp" line="-31"/>
         <source>Creation of a clone</source>
         <translation>Création d&apos;un clone</translation>
     </message>
@@ -321,7 +321,7 @@ actuelle
     <name>t_DlgAcquire</name>
     <message>
         <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+346"/>
+        <location filename="table.cpp" line="+351"/>
         <source>EwfCaseNumber</source>
         <translation>Numéro d&apos;affaire</translation>
     </message>
@@ -387,7 +387,7 @@ actuelle
         <translation>Sélectionner le répertoire de destination</translation>
     </message>
     <message>
-        <location line="+309"/>
+        <location line="+310"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation>Charactères spéciaux</translation>
@@ -413,7 +413,7 @@ Acceptez-vous ces changement?</translation>
         <translation>Répertoire info</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1075"/>
+        <location filename="dlgacquire.cpp" line="-1076"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation>...</translation>
@@ -479,7 +479,7 @@ possiblement à cause de droits d&apos;accès insuffisants. Veuillez choisir un
         <translation>Bon pour clonage</translation>
     </message>
     <message>
-        <location line="+862"/>
+        <location line="+863"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation>La taille des fragments pour le format EWF configuré doit être comprise entre %1 et %2 MiB. Des fichiers plus grands sont possibles en utilisant les format Encase6 ou Guymager (voir fichier de configuration, paramètre EwfFormat).</translation>
     </message>
@@ -502,7 +502,7 @@ Acceptez-vous ces changement?</translation>
         <translation>Les fichiers image ou info de ce nom existent déjà. Voulez vous les réécrire?</translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-882"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation>Cloner %1</translation>
@@ -540,19 +540,19 @@ Acceptez-vous ces changement?</translation>
     </message>
     <message>
         <location line="+618"/>
-        <location line="+15"/>
+        <location line="+16"/>
         <location line="+12"/>
         <source>Incorrect value</source>
         <comment>Dialog title</comment>
         <translation>Valeur non-valable</translation>
     </message>
     <message>
-        <location line="-26"/>
+        <location line="-27"/>
         <source>The split file size &quot;%1&quot; is not valid. Only positive numbers can be entered.</source>
         <translation>La valeur %1 pour la taille des fragments n&apos;est pas valable. Veuillez entrer une valuer positive.</translation>
     </message>
     <message>
-        <location line="+163"/>
+        <location line="+164"/>
         <source>Files already used</source>
         <comment>Dialog title</comment>
         <translation>Fichiers déjà utilisés</translation>
@@ -624,7 +624,7 @@ Voulez vous toujours lancer l&apos;acquisition?</translation>
         <translation>Calculer SHA-1</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1096"/>
+        <location filename="dlgacquire.cpp" line="-1097"/>
         <source>Selected for first acquisition</source>
         <translation>Déjà selectionné pour la 1ère acquisition</translation>
     </message>
@@ -656,7 +656,7 @@ doesn&apos;t exist. Do you want to create it?</source>
 n&apos;existe pas. Voulez-vous de créer?</translation>
     </message>
     <message>
-        <location line="+169"/>
+        <location line="+170"/>
         <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
         <translation>Les noms des répertoires ou fichiers contiennent des charactères spéciaux qui ne peuvent être utilisés. Guymager vous propose les modifications suivantes:</translation>
     </message>
@@ -713,7 +713,7 @@ Do you accept these changes?</source>
         <translation>Le fichier info indiquée sera déjà utilisé pour le premier fichier image.</translation>
     </message>
     <message>
-        <location line="-595"/>
+        <location line="-596"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation>Retour...</translation>
@@ -730,7 +730,7 @@ Do you accept these changes?</source>
         <translation>Paramètres de l&apos;image dupliquée</translation>
     </message>
     <message>
-        <location line="+906"/>
+        <location line="+907"/>
         <source>There possibly is not enough space left on the destination path.
 Source data size: %1
 Free space on destination: %2
@@ -1018,7 +1018,7 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>A propos de &amp;Qt</translation>
     </message>
     <message>
-        <location line="+181"/>
+        <location line="+180"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation>Média déjà existant</translation>
@@ -1040,11 +1040,46 @@ Guymager set terminera automatiquement dans %1 secondes.</translation>
         <translation>Information «debug»</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+18"/>
+        <location line="+14"/>
         <source>About GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>A propos de GUYMAGER</translation>
     </message>
+    <message>
+        <location line="-13"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Linked with libewf %5 %6</source>
+        <translation>GUYMAGER est un outil d&apos;acquisition forensique basé sur Linux
+
+Version: %1
+Date et heure de compilation: %2
+Compilé avec gcc %3
+Utilise libguytools %4
+Utilise libewf %5 %6</translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</source>
+        <translation>GUYMAGER est un outil d&apos;acquisition forensique basé sur Linux
+
+Version: %1
+Date et heure de compilation: %2
+Compilé avec gcc %3
+Utilise libguytools %4
+Compilé sans support pour libewf.</translation>
+    </message>
     <message>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
@@ -1116,7 +1151,7 @@ Utilise libguytools %5</translation>
         <translation>Oui</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-446"/>
+        <location filename="mainwindow.cpp" line="-462"/>
         <source>Rescan devices and update table</source>
         <translation>Actualiser la liste des médias connectés</translation>
     </message>
@@ -1127,7 +1162,7 @@ Utilise libguytools %5</translation>
         <translation>Ajouter média spécial</translation>
     </message>
     <message>
-        <location line="+161"/>
+        <location line="+160"/>
         <source>Open File</source>
         <translation>Ouvrir fichier</translation>
     </message>
@@ -1186,7 +1221,7 @@ Utilise libguytools %5</translation>
         <translation>non-détectable</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-179"/>
+        <location filename="mainwindow.cpp" line="-178"/>
         <source>Exit after acquisitions completed</source>
         <translation>Terminer Guymager à la fin des acquisitions</translation>
     </message>
@@ -1199,12 +1234,11 @@ Utilise libguytools %5</translation>
         <translation type="obsolete">Abandon - Démarrage échoué</translation>
     </message>
     <message>
-        <location line="+417"/>
+        <location line="+416"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation>(inactif, Guymager est configuré d&apos;utiliser son propre module EWF)</translation>
     </message>
     <message>
-        <location line="+3"/>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
 Version: %1
@@ -1212,7 +1246,7 @@ Compilation timestamp: %2
 Compiled with gcc %3
 Linked with libewf %4 %5
 Linked with libguytools %6</source>
-        <translation>GUYMAGER est un outil d&apos;acquisition forensique basé sur Linux
+        <translation type="vanished">GUYMAGER est un outil d&apos;acquisition forensique basé sur Linux
 
 Version: %1
 Date et heure de compilation: %2
@@ -1367,7 +1401,7 @@ Utilise libguytools %6</translation>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-228"/>
+        <location filename="table.cpp" line="-233"/>
         <source>Info</source>
         <comment>Context menu</comment>
         <translation>Info</translation>
@@ -1384,19 +1418,38 @@ Utilise libguytools %6</translation>
         <translation>Info média</translation>
     </message>
     <message>
-        <location line="+26"/>
+        <location line="+25"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation>FICHIER D&apos;INFORMATION POUR ACQUISITION GUYMAGER</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+12"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation>Guymager</translation>
     </message>
     <message>
-        <location line="+7"/>
+        <location line="+8"/>
+        <source>(not used as Guymager is configured to use its own EWF module)</source>
+        <comment>Info file</comment>
+        <translation>(inactif, Guymager est configuré d&apos;utiliser son propre module EWF)</translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>libewf version:: %1 %2</source>
+        <comment>Info file</comment>
+        <translation>Version:: %1 %2</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Using Guymager&apos;s own EWF module</source>
+        <oldsource>No libewf support, using Guymager&apos;s own EWF module</oldsource>
+        <comment>Info file</comment>
+        <translation>Utilisation du module EWF interne propre à Guymager</translation>
+    </message>
+    <message>
+        <location line="+3"/>
         <source>Host name:: %1</source>
         <comment>Info file</comment>
         <translation>Hôte:: %1</translation>
@@ -1552,7 +1605,7 @@ Utilise libguytools %6</translation>
         <translation>Hash MD5:: %1</translation>
     </message>
     <message>
-        <location line="-619"/>
+        <location line="-626"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation>Version:: %1</translation>
@@ -1570,13 +1623,12 @@ Utilise libguytools %6</translation>
         <translation>Compilé avec gcc:: %1 %2</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>libewf version:: %1</source>
         <comment>Info file</comment>
-        <translation>Version:: %1</translation>
+        <translation type="vanished">Version:: %1</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+9"/>
         <source>libguytools version:: %1</source>
         <comment>Info file</comment>
         <translation>Version libguytools:: %1</translation>
@@ -1724,13 +1776,13 @@ Utilise libguytools %6</translation>
         <translation>Vous pouvez essayer une nouvelle acquisition du média.</translation>
     </message>
     <message>
-        <location line="-839"/>
+        <location line="-844"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation>Effacer média spécial</translation>
     </message>
     <message>
-        <location line="+222"/>
+        <location line="+227"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation>Méta-données du fichier image</translation>
@@ -1742,7 +1794,7 @@ Utilise libguytools %6</translation>
         <translation> - l&apos;extension fichier est %1</translation>
     </message>
     <message>
-        <location line="-222"/>
+        <location line="-227"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation>Acquérir image</translation>
@@ -1760,7 +1812,7 @@ Utilise libguytools %6</translation>
         <translation>Abandonner</translation>
     </message>
     <message>
-        <location line="+212"/>
+        <location line="+217"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation>Acquisition</translation>
@@ -1772,12 +1824,12 @@ Utilise libguytools %6</translation>
         <translation>Format:: %1</translation>
     </message>
     <message>
-        <location line="-178"/>
+        <location line="-183"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation>Occupé par opération de clonage - ne peut être  acquéré</translation>
     </message>
     <message>
-        <location line="+861"/>
+        <location line="+866"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation>Fichiers image et leur valeurs hash MD5</translation>
@@ -1797,12 +1849,12 @@ Utilise libguytools %6</translation>
         <translation>Valeurs hashs MD5 non disponibles (le paramètre de configuration CalcImageFileMD5 est désactivé)</translation>
     </message>
     <message>
-        <location line="-876"/>
+        <location line="-881"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation>Ne peut être acquéré - voir informations d&apos;état suppl.</translation>
     </message>
     <message>
-        <location line="+734"/>
+        <location line="+739"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation>Abandonné à cause d&apos;une erreur lors de l&apos;écriture du fichier info</translation>
