@@ -24,12 +24,12 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+26"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+579"/>
+        <location filename="main.cpp" line="+581"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -41,7 +41,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1482"/>
+        <location filename="threadwrite.cpp" line="+1491"/>
         <source>Deleting %1</source>
         <translation type="unfinished"></translation>
     </message>
@@ -71,7 +71,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-29"/>
+        <location filename="file.cpp" line="-31"/>
         <source>Creation of a clone</source>
         <translation type="unfinished"></translation>
     </message>
@@ -217,7 +217,7 @@ Continue anyway?</source>
     <name>t_DlgAcquire</name>
     <message>
         <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+346"/>
+        <location filename="table.cpp" line="+351"/>
         <source>EwfCaseNumber</source>
         <translation type="unfinished"></translation>
     </message>
@@ -283,7 +283,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+309"/>
+        <location line="+310"/>
         <source>Special characters</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -299,7 +299,7 @@ Continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1075"/>
+        <location filename="dlgacquire.cpp" line="-1076"/>
         <source>...</source>
         <comment>The directory browse button</comment>
         <translation type="unfinished"></translation>
@@ -363,7 +363,7 @@ This may be due to insufficient access rights or unsupported filename characters
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+862"/>
+        <location line="+863"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation type="unfinished"></translation>
     </message>
@@ -390,7 +390,7 @@ This may be due to insufficient access rights or unsupported filename characters
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-882"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation type="unfinished"></translation>
@@ -428,19 +428,19 @@ This may be due to insufficient access rights or unsupported filename characters
     </message>
     <message>
         <location line="+618"/>
-        <location line="+15"/>
+        <location line="+16"/>
         <location line="+12"/>
         <source>Incorrect value</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-26"/>
+        <location line="-27"/>
         <source>The split file size &quot;%1&quot; is not valid. Only positive numbers can be entered.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+202"/>
+        <location line="+203"/>
         <source>The info file already exists. Do you want to overwrite it?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -478,7 +478,7 @@ Do you accept such a large amount of files?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1096"/>
+        <location filename="dlgacquire.cpp" line="-1097"/>
         <source>Selected for first acquisition</source>
         <translation type="unfinished"></translation>
     </message>
@@ -508,7 +508,7 @@ doesn&apos;t exist. Do you want to create it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+169"/>
+        <location line="+170"/>
         <source>The directory or file names contain special characters which are not allowed. Guymager suggests the following changes:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -565,7 +565,7 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-595"/>
+        <location line="-596"/>
         <location line="+21"/>
         <source>Back...</source>
         <translation type="unfinished"></translation>
@@ -582,7 +582,7 @@ Do you accept these changes?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+906"/>
+        <location line="+907"/>
         <source>There possibly is not enough space left on the destination path.
 Source data size: %1
 Free space on destination: %2
@@ -837,7 +837,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+181"/>
+        <location line="+180"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -859,11 +859,34 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+18"/>
+        <location line="+14"/>
         <source>About GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location line="-13"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Linked with libewf %5 %6</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location line="+16"/>
         <source>About Qt</source>
@@ -899,7 +922,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-446"/>
+        <location filename="mainwindow.cpp" line="-462"/>
         <source>Rescan devices and update table</source>
         <translation type="unfinished"></translation>
     </message>
@@ -910,7 +933,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+161"/>
+        <location line="+160"/>
         <source>Open File</source>
         <translation type="unfinished"></translation>
     </message>
@@ -964,26 +987,15 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-179"/>
+        <location filename="mainwindow.cpp" line="-178"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+417"/>
+        <location line="+416"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location line="+3"/>
-        <source>GUYMAGER is a Linux-based forensic imaging tool
-
-Version: %1
-Compilation timestamp: %2
-Compiled with gcc %3
-Linked with libewf %4 %5
-Linked with libguytools %6</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="device.cpp" line="-468"/>
         <source>Acquisition start failure</source>
@@ -1126,7 +1138,7 @@ Linked with libguytools %6</source>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-228"/>
+        <location filename="table.cpp" line="-233"/>
         <source>Info</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
@@ -1143,19 +1155,19 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+26"/>
+        <location line="+25"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+12"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+14"/>
+        <location line="+21"/>
         <source>Device information</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1288,7 +1300,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-619"/>
+        <location line="-626"/>
         <source>Version:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1306,13 +1318,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+1"/>
-        <source>libewf version:: %1</source>
-        <comment>Info file</comment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location line="+1"/>
+        <location line="+9"/>
         <source>libguytools version:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1354,7 +1360,26 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-36"/>
+        <location line="-42"/>
+        <source>(not used as Guymager is configured to use its own EWF module)</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>libewf version:: %1 %2</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Using Guymager&apos;s own EWF module</source>
+        <oldsource>No libewf support, using Guymager&apos;s own EWF module</oldsource>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+3"/>
         <source>Host name:: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1458,13 +1483,13 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-839"/>
+        <location line="-844"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+222"/>
+        <location line="+227"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1476,7 +1501,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-222"/>
+        <location line="-227"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation type="unfinished"></translation>
@@ -1494,7 +1519,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+212"/>
+        <location line="+217"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1506,12 +1531,12 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-178"/>
+        <location line="-183"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+861"/>
+        <location line="+866"/>
         <source>Generated image files and their MD5 hashes</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1527,12 +1552,12 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="-876"/>
+        <location line="-881"/>
         <source>Cannot be acquired - see additional state info field</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+734"/>
+        <location line="+739"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
