@@ -24,7 +24,7 @@
         <translation>Linux dd &quot;raw&quot; image</translation>
     </message>
     <message>
-        <location line="+24"/>
+        <location line="+26"/>
         <source>Expert Witness Format, sub-format %1</source>
         <translation>Expert Witness Formaat, sub-formaat %1</translation>
     </message>
@@ -34,7 +34,7 @@
         <translation>Advanced forensic image</translation>
     </message>
     <message>
-        <location filename="main.cpp" line="+579"/>
+        <location filename="main.cpp" line="+581"/>
         <source>Missing root rights</source>
         <comment>Dialog title</comment>
         <translation>Root rechten benodigd</translation>
@@ -46,7 +46,7 @@ Continue anyway?</source>
         <translation>Guymager moet gestart worden met &quot;root&quot;-rechten om media veilig te kunnen stellen. U bent op dit moment geen &quot;root&quot;, en daarom zult u geen media veilig kunnen stellen.</translation>
     </message>
     <message>
-        <location filename="threadwrite.cpp" line="+1482"/>
+        <location filename="threadwrite.cpp" line="+1491"/>
         <source>Deleting %1</source>
         <translation>%1 aan het verwijderen</translation>
     </message>
@@ -71,7 +71,7 @@ Continue anyway?</source>
         <translation>Probeer methode &quot;%1&quot;</translation>
     </message>
     <message>
-        <location filename="file.cpp" line="-29"/>
+        <location filename="file.cpp" line="-31"/>
         <source>Creation of a clone</source>
         <translation>Maak een exacte kopie (&quot;Clone&quot;)</translation>
     </message>
@@ -286,7 +286,7 @@ usage
     <name>t_DlgAcquire</name>
     <message>
         <location filename="config.h" line="+278"/>
-        <location filename="table.cpp" line="+346"/>
+        <location filename="table.cpp" line="+351"/>
         <source>EwfCaseNumber</source>
         <translation>Zaaknummer</translation>
     </message>
@@ -368,7 +368,7 @@ usage
         <translation>Selecteer de bestemmingsmap</translation>
     </message>
     <message>
-        <location line="+265"/>
+        <location line="+266"/>
         <source>The split size for the configured EWF format must be in the range %1 - %2 MiB. For bigger files, switch to Encase6 format or Guymager (see Guymager configuration file, parameter EwfFormat).</source>
         <translation type="unfinished"></translation>
     </message>
@@ -389,7 +389,7 @@ Do you accept these changes?</source>
 Wilt u deze wijzigingen accepteren?</translation>
     </message>
     <message>
-        <location line="-117"/>
+        <location line="-118"/>
         <source>Access denied</source>
         <comment>Dialog title</comment>
         <translation>Toegang verboden</translation>
@@ -457,7 +457,7 @@ Do you accept these changes?</source>
 Wilt u deze wijzigingen accepteren?</translation>
     </message>
     <message>
-        <location line="+1036"/>
+        <location line="+1037"/>
         <source>Files exist</source>
         <comment>Dialog title</comment>
         <translation>Bestand bestaat reeds</translation>
@@ -468,7 +468,7 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation>Het image- of infobestand bestaat al. Overschrijven?</translation>
     </message>
     <message>
-        <location line="-881"/>
+        <location line="-882"/>
         <source>Clone %1</source>
         <comment>Dialog title, %1 is the device (for instance /dev/hdc)</comment>
         <translation>Kloon %1</translation>
@@ -506,19 +506,19 @@ Wilt u deze wijzigingen accepteren?</translation>
     </message>
     <message>
         <location line="+618"/>
-        <location line="+15"/>
+        <location line="+16"/>
         <location line="+12"/>
         <source>Incorrect value</source>
         <comment>Dialog title</comment>
         <translation>Incorrecte waarde</translation>
     </message>
     <message>
-        <location line="-26"/>
+        <location line="-27"/>
         <source>The split file size &quot;%1&quot; is not valid. Only positive numbers can be entered.</source>
         <translation>De grootte van de delen van het bestand is niet correct. Alleen positieve getallen kunnen ingevoerd worden.</translation>
     </message>
     <message>
-        <location line="+202"/>
+        <location line="+203"/>
         <source>The info file already exists. Do you want to overwrite it?</source>
         <translation>Het infobestand bestaat al. Wilt u het overschrijven?</translation>
     </message>
@@ -537,7 +537,7 @@ Wilt u deze wijzigingen accepteren?</translation>
         <translation type="unfinished">Bereken SHA-1</translation>
     </message>
     <message>
-        <location filename="dlgacquire.cpp" line="-1039"/>
+        <location filename="dlgacquire.cpp" line="-1040"/>
         <source>Selected for first acquisition</source>
         <translation type="unfinished"></translation>
     </message>
@@ -584,7 +584,7 @@ doesn&apos;t exist. Do you want to create it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+120"/>
+        <location line="+121"/>
         <source>The split size for the selected image format must be in the range %1MiB - %2EiB.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -982,7 +982,7 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation>Over &amp;Qt&gt;</translation>
     </message>
     <message>
-        <location line="+181"/>
+        <location line="+180"/>
         <source>Device already contained</source>
         <comment>Dialog title</comment>
         <translation type="unfinished"></translation>
@@ -1004,11 +1004,34 @@ Guymager will exit automatically in %1 seconds.</source>
         <translation>Debug informatie</translation>
     </message>
     <message>
-        <location line="+16"/>
+        <location line="+18"/>
+        <location line="+14"/>
         <source>About GUYMAGER</source>
         <comment>Dialog title</comment>
         <translation>Over GUYMAGER</translation>
     </message>
+    <message>
+        <location line="-13"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Linked with libewf %5 %6</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+14"/>
+        <source>GUYMAGER is a Linux-based forensic imaging tool
+
+Version: %1
+Compilation timestamp: %2
+Compiled with gcc %3
+Linked with libguytools %4
+Compiled without libewf support</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>GUYMAGER is a Linux-based forensic imaging tool
 
@@ -1062,7 +1085,7 @@ Using libguytools %5</translation>
         <translation>Ja</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-446"/>
+        <location filename="mainwindow.cpp" line="-462"/>
         <source>Rescan devices and update table</source>
         <translation>Herscan de apparaten en ververs de tabel</translation>
     </message>
@@ -1073,7 +1096,7 @@ Using libguytools %5</translation>
         <translation>Voeg speciaal apparaat toe</translation>
     </message>
     <message>
-        <location line="+161"/>
+        <location line="+160"/>
         <source>Open File</source>
         <translation>Open bestand</translation>
     </message>
@@ -1265,31 +1288,20 @@ Using libguytools %5</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="-179"/>
+        <location filename="mainwindow.cpp" line="-178"/>
         <source>Exit after acquisitions completed</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+417"/>
+        <location line="+416"/>
         <source>(not used as Guymager currently is configured to use its own EWF module)</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location line="+3"/>
-        <source>GUYMAGER is a Linux-based forensic imaging tool
-
-Version: %1
-Compilation timestamp: %2
-Compiled with gcc %3
-Linked with libewf %4 %5
-Linked with libguytools %6</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>t_Table</name>
     <message>
-        <location filename="table.cpp" line="-228"/>
+        <location filename="table.cpp" line="-233"/>
         <source>Info</source>
         <comment>Context menu</comment>
         <translation>Informatie</translation>
@@ -1306,13 +1318,13 @@ Linked with libguytools %6</source>
         <translation>Apparaat info</translation>
     </message>
     <message>
-        <location line="+26"/>
+        <location line="+25"/>
         <source>GUYMAGER ACQUISITION INFO FILE</source>
         <comment>Info file</comment>
         <translation>GUYMANAGER INFO BESTAND VEILIGSTELLEN</translation>
     </message>
     <message>
-        <location line="+13"/>
+        <location line="+12"/>
         <source>Guymager</source>
         <comment>Info file</comment>
         <translation>Info bestand</translation>
@@ -1336,13 +1348,12 @@ Linked with libguytools %6</source>
         <translation>Gecompileerd met:: %1 %2</translation>
     </message>
     <message>
-        <location line="+1"/>
         <source>libewf version:: %1</source>
         <comment>Info file</comment>
-        <translation>libewf versie:: %1</translation>
+        <translation type="vanished">libewf versie:: %1</translation>
     </message>
     <message>
-        <location line="+1"/>
+        <location line="+9"/>
         <source>libguytools version:: %1</source>
         <comment>Info file</comment>
         <translation>libguytools versie:: %1</translation>
@@ -1646,13 +1657,13 @@ Linked with libguytools %6</source>
         <translation>U kunt proberen om het apparaat nogmaals veilig te stellen.</translation>
     </message>
     <message>
-        <location line="-839"/>
+        <location line="-844"/>
         <source>Remove special device</source>
         <comment>Context menu</comment>
         <translation>Verwijder speciaal apparaat</translation>
     </message>
     <message>
-        <location line="+222"/>
+        <location line="+227"/>
         <source>Image meta data</source>
         <comment>Info file</comment>
         <translation>Image meta data</translation>
@@ -1664,7 +1675,7 @@ Linked with libguytools %6</source>
         <translation> - Bestandsextensie is %1</translation>
     </message>
     <message>
-        <location line="-222"/>
+        <location line="-227"/>
         <source>Acquire image</source>
         <comment>Context menu</comment>
         <translation>Veiligstellen</translation>
@@ -1682,7 +1693,7 @@ Linked with libguytools %6</source>
         <translation>Afbreken</translation>
     </message>
     <message>
-        <location line="+212"/>
+        <location line="+217"/>
         <source>Acquisition</source>
         <comment>Info file</comment>
         <translation>Veiligstellen</translation>
@@ -1694,7 +1705,7 @@ Linked with libguytools %6</source>
         <translation>Formaat:: %1</translation>
     </message>
     <message>
-        <location line="-178"/>
+        <location line="-183"/>
         <source>Device used for cloning - cannot be acquired</source>
         <translation>Apparaat in gebruik voor klonen - kan niet veiliggesteld worden</translation>
     </message>
@@ -1704,7 +1715,7 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+167"/>
+        <location line="+172"/>
         <source>Hidden areas: %1</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
@@ -1728,7 +1739,26 @@ Linked with libguytools %6</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location line="+21"/>
+        <location line="-564"/>
+        <source>(not used as Guymager is configured to use its own EWF module)</source>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+1"/>
+        <source>libewf version:: %1 %2</source>
+        <comment>Info file</comment>
+        <translation type="unfinished">libewf versie:: %1 %2</translation>
+    </message>
+    <message>
+        <location line="+2"/>
+        <source>Using Guymager&apos;s own EWF module</source>
+        <oldsource>No libewf support, using Guymager&apos;s own EWF module</oldsource>
+        <comment>Info file</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location line="+582"/>
         <source>Aborted because of info file write error</source>
         <comment>Info file</comment>
         <translation type="unfinished"></translation>
