@@ -10,7 +10,7 @@
 //                  in t_Table.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -33,6 +33,7 @@
 #else
    #include <QtGui>     //lint !e537 Repeated include
 #endif
+#include <QFontMetrics>
 
 #include "common.h"
 #include "itemdelegate.h"
@@ -91,10 +92,12 @@ void t_ItemDelegate::PaintDefaults (QPainter *pPainter, const QStyleOptionViewIt
 void t_ItemDelegate::PaintProgress (QPainter *pPainter, const QStyleOptionViewItem &Option, const QModelIndex &Index) const
 {
    t_pDevice pDev;
-   QRect      BarRect;
-   QColor     ColorPen;
-   double     ProgressFactor;
-
+   QRect        BarRect;
+   QRect        TextRect;
+   QColor       ColorPen;
+   double       ProgressFactor;
+   int          BarSep;
+   
    pPainter->save();
    PaintDefaults (pPainter, Option, Index, ColorPen);
 
@@ -102,12 +105,18 @@ void t_ItemDelegate::PaintProgress (QPainter *pPainter, const QStyleOptionViewIt
    if (!pDev->StartTimestamp.isNull())
    {
       ProgressFactor = Index.data (Qt::DisplayRole).toDouble();
+
+      BarSep = Option.rect.height() - pPainter->fontMetrics().ascent(); // Keep enough space above bar for percentage count
+
       BarRect = Option.rect;
-      BarRect.adjust (10, 20, -10, -4);
+      BarRect.adjust (10, BarSep, -10, -4);  // keep progress bar rectangle at 10 px from left and right and 4 px from bottom
       pPainter->setBrush (Qt::NoBrush);
       pPainter->setPen   (ColorPen);
       pPainter->drawRect (BarRect);
-      pPainter->drawText (Option.rect, Qt::AlignHCenter | Qt::AlignCenter, QString ("%1%") .arg ((int)(ProgressFactor*100)) );
+
+      TextRect = Option.rect;
+      TextRect.setHeight (BarSep + pPainter->fontMetrics().descent()/2); // As we only show now numbers and thus not use the descent space (unlike g, j etc.) we move down the text a bit to make it appear vertically centered in the foreseen text area
+      pPainter->drawText (TextRect, Qt::AlignHCenter | Qt::AlignCenter, QString ("%1%") .arg ((int)(ProgressFactor*100)) );
 
       pPainter->setBrush (ColorPen);
       pPainter->setPen   (Qt::NoPen);
