@@ -11,7 +11,7 @@
 //                  deinitialisation.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -51,7 +51,7 @@
 #include "toolsysinfo.h"
 #include "toolcfg.h"
 
-#include "libewf.h"
+#include "ewf.h"
 
 #include "compileinfo.h"
 #include "config.h"
@@ -377,7 +377,6 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    APIRET          Err = NO_ERROR;
    APIRET          rc;
    int             RetCode;
-   const char    *pLibEwfVersionInstalled;
    const char    *pLibGuyToolsVersionInstalled;
    quint64         FifoAllocs;
    quint64         FifoFrees;
@@ -416,9 +415,12 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
    LOG_INFO ("System: %s", QSTR_TO_PSZ(Uname))
 
    t_Log::GetLibGuyToolsVersion (&pLibGuyToolsVersionInstalled);
-   pLibEwfVersionInstalled = (const char *) libewf_get_version();
    LOG_INFO ("Libguytools version installed on this PC: %s", pLibGuyToolsVersionInstalled)
-   LOG_INFO ("Libewf      version installed on this PC: %s", pLibEwfVersionInstalled)
+   #if (ENABLE_LIBEWF)
+      LOG_INFO ("Libewf      version installed on this PC: %s", (const char *) libewf_get_version())
+   #else
+      LOG_INFO ("Compiled without libewf support")
+   #endif
 
    unsigned long long Bytes = UtilGetInstalledRAM ();
    LOG_INFO ("Total amount of memory installed: %0.1f MB", Bytes/(1024.0*1024.0))
@@ -625,15 +627,14 @@ static APIRET MainGo (int argc, char *argv[], bool *pAutoExit)
 
    // Initialise libewf
    // -----------------
-   #if ((LIBEWF_VERSION != 20080501) && (LIBEWF_VERSION != 20100226) && (LIBEWF_VERSION != 20111015) && (LIBEWF_VERSION < 20130416))
-      #error "Please check EWF documentation for newer Encase formats and adjust following code"
-   #endif
-
-   #if (LIBEWF_VERSION >= 20130416)
-      libewf_notify_set_stream  (stderr, NULL);
-      libewf_notify_set_verbose (CONFIG (VerboseLibewf) ? 1 : 0);
-   #else
-      libewf_set_notify_values (stderr, CONFIG (VerboseLibewf) ? 1 : 0);
+   
+   #if (ENABLE_LIBEWF)
+      #if (LIBEWF_VERSION >= 20130416)
+         libewf_notify_set_stream  (stderr, NULL);
+         libewf_notify_set_verbose (CONFIG (VerboseLibewf) ? 1 : 0);
+      #else
+         libewf_set_notify_values (stderr, CONFIG (VerboseLibewf) ? 1 : 0);
+      #endif
    #endif
 
    // Create central data structures
