@@ -10,7 +10,7 @@
 //                  widget
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -36,7 +36,7 @@
 
 #include "common.h"
 
-#include "libewf.h"
+#include "ewf.h"
 
 #include "config.h"
 #include "compileinfo.h"
@@ -380,7 +380,6 @@ t_MainWindow::t_MainWindow (t_pDeviceList pDeviceList, QWidget *pParent, Qt::Win
 
    // Start the device scan thread
    // ----------------------------
-
    pOwn->pThreadScan = new t_ThreadScan ();
    CHK_EXIT (pOwn->pThreadScan->Start (&pOwn->pScanWorker))
    CHK_QT_EXIT (connect (pOwn->pActionRescan, SIGNAL (triggered ()),          pOwn->pScanWorker, SLOT (SlotRescan       ())))
@@ -711,28 +710,45 @@ void t_MainWindow::SlotDebug (void)
 void t_MainWindow::SlotAboutGuymager (void)
 {
    const char *pLibGuyToolsVersionInstalled;
-   const char *pLibEwfVersionInstalled;
-   QString      EwfRemark;
 
    t_Log::GetLibGuyToolsVersion (&pLibGuyToolsVersionInstalled);
+   #if (ENABLE_LIBEWF)
+      const char *pLibEwfVersionInstalled;
+      QString      EwfRemark;
 
-   pLibEwfVersionInstalled = (const char *) libewf_get_version ();
+      pLibEwfVersionInstalled = (const char *) libewf_get_version ();
+      if (CONFIG(EwfFormat) == t_File::AEWF)
+         EwfRemark = tr("(not used as Guymager currently is configured to use its own EWF module)");
+   #endif
 
-   if (CONFIG(EwfFormat) == t_File::AEWF)
-        EwfRemark = tr("(not used as Guymager currently is configured to use its own EWF module)");
-   else EwfRemark = "";
-   QMessageBox::about(this, tr("About GUYMAGER", "Dialog title"),
-                            tr("GUYMAGER is a Linux-based forensic imaging tool\n\n"
-                               "Version: %1\n"
-                               "Compilation timestamp: %2\n"
-                               "Compiled with gcc %3\n"
-                               "Linked with libewf %4 %5\n"
-                               "Linked with libguytools %6")
-                               .arg(pCompileInfoVersion)
-                               .arg(pCompileInfoTimestamp)
-                               .arg(__VERSION__)
-                               .arg(pLibEwfVersionInstalled) .arg(EwfRemark)
-                               .arg(pLibGuyToolsVersionInstalled));
+   #if (ENABLE_LIBEWF)  // Do not factorise the code below, as Qt Linguist will problems otherwise
+      QMessageBox::about(this, tr("About GUYMAGER", "Dialog title"),
+                               tr("GUYMAGER is a Linux-based forensic imaging tool\n\n"
+                                  "Version: %1\n"
+                                  "Compilation timestamp: %2\n"
+                                  "Compiled with gcc %3\n"
+                                  "Linked with libguytools %4\n"
+                                  "Linked with libewf %5 %6")
+                                  .arg(pCompileInfoVersion)
+                                  .arg(pCompileInfoTimestamp)
+                                  .arg(__VERSION__)
+                                  .arg(pLibGuyToolsVersionInstalled)
+                                  .arg(pLibEwfVersionInstalled) .arg(EwfRemark)
+                                  );
+   #else
+      QMessageBox::about(this, tr("About GUYMAGER", "Dialog title"),
+                               tr("GUYMAGER is a Linux-based forensic imaging tool\n\n"
+                                  "Version: %1\n"
+                                  "Compilation timestamp: %2\n"
+                                  "Compiled with gcc %3\n"
+                                  "Linked with libguytools %4\n"
+                                  "Compiled without libewf support")
+                                  .arg(pCompileInfoVersion)
+                                  .arg(pCompileInfoTimestamp)
+                                  .arg(__VERSION__)
+                                  .arg(pLibGuyToolsVersionInstalled)
+                                  );
+   #endif
 }
 
 void t_MainWindow::SlotAboutQt (void)
