@@ -9,7 +9,7 @@
 //  Module:         The table widget (central widget of the application)
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -283,7 +283,6 @@ APIRET t_Table::ShowDeviceInfo (t_pcDevice pDevice)
 APIRET t_Table::InfoAcquisitionStart (t_pAcquisition pAcquisition)
 {
    const char *pLibGuyToolsVersionInstalled;
-   const char *pLibEwfVersionInstalled;
    QString      FormatDescription;
    QString      FormatExtension;
    QString      Str;
@@ -297,7 +296,6 @@ APIRET t_Table::InfoAcquisitionStart (t_pAcquisition pAcquisition)
    CHK (pAcquisition->Info.Title   (tr("GUYMAGER ACQUISITION INFO FILE", "Info file")))
 
    t_Log::GetLibGuyToolsVersion (&pLibGuyToolsVersionInstalled);
-   pLibEwfVersionInstalled = (const char *) libewf_get_version ();
    CHK (ToolSysInfoUname (Uname))
    pHostname   = (char *) Hostname.GetpMem();
    pDomainname = (char *) Domainname.GetpMem();
@@ -312,7 +310,14 @@ APIRET t_Table::InfoAcquisitionStart (t_pAcquisition pAcquisition)
    CHK (pAcquisition->Info.AddRow (tr("Version:: %1"              , "Info file") .arg(pCompileInfoVersion  )))
    CHK (pAcquisition->Info.AddRow (tr("Compilation timestamp:: %1", "Info file") .arg(pCompileInfoTimestamp)))
    CHK (pAcquisition->Info.AddRow (tr("Compiled with:: %1 %2"     , "Info file") .arg("gcc") .arg(__VERSION__)))
-   CHK (pAcquisition->Info.AddRow (tr("libewf version:: %1"       , "Info file") .arg(pLibEwfVersionInstalled     )))
+   #if (ENABLE_LIBEWF)
+      QString EwfRemark;
+      if (CONFIG(EwfFormat) == t_File::AEWF)
+         EwfRemark = tr("(not used as Guymager is configured to use its own EWF module)", "Info file");
+      CHK (pAcquisition->Info.AddRow (tr("libewf version:: %1 %2" , "Info file") .arg((const char *) libewf_get_version()) .arg(EwfRemark)))
+   #else
+      CHK (pAcquisition->Info.AddRow (tr("Using Guymager's own EWF module", "Info file")));
+   #endif
    CHK (pAcquisition->Info.AddRow (tr("libguytools version:: %1"  , "Info file") .arg(pLibGuyToolsVersionInstalled)))
    CHK (pAcquisition->Info.AddRow (tr("Host name:: %1"            , "Info file") .arg(pHostname)))
    CHK (pAcquisition->Info.AddRow (tr("Domain name:: %1"          , "Info file") .arg(pDomainname)))
