@@ -9,7 +9,7 @@
 //  Module:         Multi-threaded compression
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -110,26 +110,30 @@ void t_ThreadCompress::run (void)
    bool            Finished  = false;
    quint64         Blocks    = 0;
    const int       SubFifoNr = pOwn->ThreadNr;
-   size_t          CompressedMaxSize = 0;
-   size_t          CompressedSize    = 0;
-   LIBEWF_HANDLE *pEwfHandle  = NULL;
-   ssize_t         rc;
+   #if (ENABLE_LIBEWF)
+      size_t          CompressedMaxSize = 0;
+      size_t          CompressedSize    = 0;
+      ssize_t         rc;
+      LIBEWF_HANDLE *pEwfHandle  = NULL;
+   #endif
 
    LOG_INFO ("[%s] Compression thread #%d started", QSTR_TO_PSZ (pOwn->pDevice->LinuxDevice), pOwn->ThreadNr)
    CHK_EXIT (SetDebugMessage ("Start run function"))
 
    pDevice  = pOwn->pDevice;
 
-   if (pDevice->Acquisition1.Format == t_File::EWF)
-   {
-      CompressedMaxSize = (size_t) (pDevice->FifoBlockSize * 1.001) + 12; // see zlib documentation
-      if (CONFIG(EwfFormat) != t_File::AEWF)
+   #if (ENABLE_LIBEWF)
+      if (pDevice->Acquisition1.Format == t_File::EWF)
       {
-         void *pHandle;
-         CHK_EXIT (pDevice->pThreadWrite1->GetpFileHandle (&pHandle))  // This handle is the reason why libewf can't
-         pEwfHandle  = (LIBEWF_HANDLE *) pHandle;                      // be used together with image duplication
+         CompressedMaxSize = (size_t) (pDevice->FifoBlockSize * 1.001) + 12; // see zlib documentation
+         if (CONFIG(EwfFormat) != t_File::AEWF)
+         {
+            void *pHandle;
+            CHK_EXIT (pDevice->pThreadWrite1->GetpFileHandle (&pHandle))  // This handle is the reason why libewf can't
+            pEwfHandle  = (LIBEWF_HANDLE *) pHandle;                      // be used together with image duplication
+         }
       }
-   }
+   #endif
 
    CHK_EXIT (pDevice->pFifoCompressIn ->GetSubFifo (SubFifoNr, pFifoIn ))
    CHK_EXIT (pDevice->pFifoCompressOut->GetSubFifo (SubFifoNr, pFifoOut))
@@ -165,46 +169,48 @@ void t_ThreadCompress::run (void)
                   }
                   break;
                }
-               else
-               {
-                  CompressedSize = CompressedMaxSize;  // Must be initialised with the max buffer size (we use this one instead of MULTITHREADED_COMPRESSION_FIFO_BLOCK_SIZE in order to check if it works as written in the zlib docu)
-                  #if (LIBEWF_VERSION < 20130416)
-                     rc = libewf_raw_write_prepare_buffer (pEwfHandle, pFifoBlockIn ->Buffer, pFifoBlockIn->DataSize,
-                                                                       pFifoBlockOut->Buffer, &CompressedSize,
-                                                                      &pFifoBlockOut->EwfCompressionUsed,
-                                                                      &pFifoBlockOut->EwfChunkCRC,
-                                                                      &pFifoBlockOut->EwfWriteCRC);
-                  #else
-                     rc = libewf_handle_prepare_write_chunk(pEwfHandle, pFifoBlockIn ->Buffer, pFifoBlockIn->DataSize,
-                                                                        pFifoBlockOut->Buffer, &CompressedSize,
-                                                                       &pFifoBlockOut->EwfCompressionUsed,
-                                                                       &pFifoBlockOut->EwfChunkCRC,
-                                                                       &pFifoBlockOut->EwfWriteCRC, NULL);
-                  #endif
-                  if (pFifoBlockOut->EwfCompressionUsed)
-                  {
-                     pFifoBlockOut->EwfDataSize = CompressedSize;                        // Data to be forwarded is contained in
-                     CHK_EXIT (t_Fifo::Destroy (pDevice->pFifoMemory, pFifoBlockIn))     // pFifoBlockOut, pFifoBlockIn no longer needed.
-                  }
+               #if (ENABLE_LIBEWF)
                   else
                   {
-                     pFifoBlockIn->EwfDataSize        = pFifoBlockIn ->DataSize;
-                     pFifoBlockIn->EwfCompressionUsed = pFifoBlockOut->EwfCompressionUsed;
-                     pFifoBlockIn->EwfChunkCRC        = pFifoBlockOut->EwfChunkCRC;
-                     pFifoBlockIn->EwfWriteCRC        = pFifoBlockOut->EwfWriteCRC;
-                     CHK_EXIT (t_Fifo::Destroy (pDevice->pFifoMemory, pFifoBlockOut))    // No compression, we'll forward the
-                     pFifoBlockOut = pFifoBlockIn;                                       // original block we received
-                  }
+                     CompressedSize = CompressedMaxSize;  // Must be initialised with the max buffer size (we use this one instead of MULTITHREADED_COMPRESSION_FIFO_BLOCK_SIZE in order to check if it works as written in the zlib docu)
+                     #if (LIBEWF_VERSION < 20130416)
+                        rc = libewf_raw_write_prepare_buffer (pEwfHandle, pFifoBlockIn ->Buffer, pFifoBlockIn->DataSize,
+                                                                         pFifoBlockOut->Buffer, &CompressedSize,
+                                                                         &pFifoBlockOut->EwfCompressionUsed,
+                                                                         &pFifoBlockOut->EwfChunkCRC,
+                                                                         &pFifoBlockOut->EwfWriteCRC);
+                     #else
+                        rc = libewf_handle_prepare_write_chunk(pEwfHandle, pFifoBlockIn ->Buffer, pFifoBlockIn->DataSize,
+                                                                           pFifoBlockOut->Buffer, &CompressedSize,
+                                                                          &pFifoBlockOut->EwfCompressionUsed,
+                                                                          &pFifoBlockOut->EwfChunkCRC,
+                                                                          &pFifoBlockOut->EwfWriteCRC, NULL);
+                     #endif
+                     if (pFifoBlockOut->EwfCompressionUsed)
+                     {
+                        pFifoBlockOut->EwfDataSize = CompressedSize;                        // Data to be forwarded is contained in
+                        CHK_EXIT (t_Fifo::Destroy (pDevice->pFifoMemory, pFifoBlockIn))     // pFifoBlockOut, pFifoBlockIn no longer needed.
+                     }
+                     else
+                     {
+                        pFifoBlockIn->EwfDataSize        = pFifoBlockIn ->DataSize;
+                        pFifoBlockIn->EwfCompressionUsed = pFifoBlockOut->EwfCompressionUsed;
+                        pFifoBlockIn->EwfChunkCRC        = pFifoBlockOut->EwfChunkCRC;
+                        pFifoBlockIn->EwfWriteCRC        = pFifoBlockOut->EwfWriteCRC;
+                        CHK_EXIT (t_Fifo::Destroy (pDevice->pFifoMemory, pFifoBlockOut))    // No compression, we'll forward the
+                        pFifoBlockOut = pFifoBlockIn;                                       // original block we received
+                     }
 
-                  if (rc != (ssize_t) pFifoBlockOut->EwfDataSize)
-                  {
-                     LOG_INFO ("[%s] libewf_raw_write_prepare_buffer returned %d. DataSize=%u, CompressedMaxSize=%zd, CompressedSize=%zd, EwfCompressionUsed=%d",
-                               QSTR_TO_PSZ (pOwn->pDevice->LinuxDevice), (int)rc,
-                               pFifoBlockOut->DataSize, CompressedMaxSize, CompressedSize, pFifoBlockOut->EwfCompressionUsed)
-                     CHK_EXIT (ERROR_THREADCOMPRESS_LIBEWF_FAILED)
+                     if (rc != (ssize_t) pFifoBlockOut->EwfDataSize)
+                     {
+                        LOG_INFO ("[%s] libewf_raw_write_prepare_buffer returned %d. DataSize=%u, CompressedMaxSize=%zd, CompressedSize=%zd, EwfCompressionUsed=%d",
+                                  QSTR_TO_PSZ (pOwn->pDevice->LinuxDevice), (int)rc,
+                                  pFifoBlockOut->DataSize, CompressedMaxSize, CompressedSize, pFifoBlockOut->EwfCompressionUsed)
+                        CHK_EXIT (ERROR_THREADCOMPRESS_LIBEWF_FAILED)
+                     }
+                     pFifoBlockOut->EwfPreprocessed = true;
                   }
-                  pFifoBlockOut->EwfPreprocessed = true;
-               }
+               #endif
                break;
 
             case t_File::AAFF:
