@@ -9,7 +9,7 @@
 //  Module:         Thread for writing data.
 // ****************************************************************************
 
-// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017 
+// Copyright 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018
 // Guy Voncken
 //
 // This file is part of Guymager.
@@ -330,6 +330,8 @@ class t_OutputFileDD: public t_OutputFile
 //                                           EWF FORMAT
 // ------------------------------------------------------------------------------------------------
 
+#if (ENABLE_LIBEWF)
+
 #if (LIBEWF_VERSION >= 20130416)
    #define CHK_LIBEWF(Fn)                                                 \
    {                                                                      \
@@ -727,6 +729,8 @@ class t_OutputFileEWF: public t_OutputFile
       bool            oHasCompressionThreads;
 };
 
+#endif // ENABLE_LIBEWF
+
 // ------------------------------------------------------------------------------------------------
 //                                           AAFF FORMAT
 // ------------------------------------------------------------------------------------------------
@@ -1288,7 +1292,12 @@ void t_ThreadWrite::run (void)
    {
       case t_File::EWF : if (CONFIG(EwfFormat) == t_File::AEWF)
                               pOutputFile = new t_OutputFileAEWF(this);
-                         else pOutputFile = new t_OutputFileEWF (this); 
+                         else 
+                              #if (ENABLE_LIBEWF)
+                                 pOutputFile = new t_OutputFileEWF (this);
+                              #else
+                                 CHK_EXIT (ERROR_THREADWRITE_INVALID_FORMAT)
+                              #endif 
                          break;
       case t_File::DD  :      pOutputFile = new t_OutputFileDD  (this); break;
       case t_File::AAFF:      pOutputFile = new t_OutputFileAAFF(this); break;
